from distutils.core import setup

setup(name='pobo',
      version='1.0.5',
      description='Python3 parser and network representation of Open Biological and Biomedical Ontologies (OBO)',
      author='XiaoGerGer',
      author_email='is.me.xiao@gmail.com',
      url='https://github.com/mschubert/python-obo',
      packages=[],
      keywords='parse obo',
      license="MIT",
      long_description=open("README.rst").read()
      )
